@@ -36,7 +36,7 @@
 #define _(string)	gettext(string)
 
 static char const rcsid[] =
-    "$Id: keybind.c,v 1.20 2003/06/24 14:55:47 jordim Exp $";
+    "$Id: keybind.c,v 1.22 2003/07/14 07:29:03 lobbin Exp $";
 
 extern SYSTEM_DATA  prefs;
 extern GConfClient	*gconf_client;
@@ -117,7 +117,8 @@ static void keybind_gconf_sync(PROFILE_DATA *pd)
 {
 	KEYBIND_DATA *entry;
 	GSList *list = NULL;
-	gchar *data, *key = g_strdup_printf("/apps/gnome-mud/profiles/%s/keybinds", pd->name);
+	gchar *pname = gconf_escape_key(pd->name, -1);
+	gchar *data, *key = g_strdup_printf("/apps/gnome-mud/profiles/%s/keybinds", pname);
 
 	for (entry = pd->kd; entry != NULL; entry = entry->next)
 	{
@@ -133,6 +134,7 @@ static void keybind_gconf_sync(PROFILE_DATA *pd)
 	gconf_client_set_list(gconf_client, key, GCONF_VALUE_STRING, list, NULL);
 
 	g_free(key);
+	g_free(pname);
 }
 
 static void keybind_button_add_clicked_cb (GtkButton *button, PROFILE_DATA *pd)
@@ -306,7 +308,7 @@ void window_keybind (PROFILE_DATA *pd)
 	gtk_widget_set_usize (window_key_bind, 450, 320);
 
 	gtk_container_set_border_width (GTK_CONTAINER (window_key_bind), 5);
-	gtk_window_set_title (GTK_WINDOW (window_key_bind), _("GNOME-Mud Key Binding Centre"));
+	gtk_window_set_title (GTK_WINDOW (window_key_bind), _("GNOME-Mud Keybinding Center"));
 	gtk_window_set_position (GTK_WINDOW (window_key_bind), GTK_WIN_POS_CENTER);
 	
 	vbox = gtk_vbox_new (FALSE, 0);
